# XlBridge Python User Library

XlBridge enables writing Excel user-defined formulas (UDFs) in C#, Python (or any programming language that
supports gRPC and protobufs).

The XlBridge Python User Library provides the functionality to expose Python formulas to the XlBridge Excel add-in.

> The XlBridge Excel add-in is non-free software, see <https://xlbridge.qaplix.se> for pricing and trial version availability.
